Serialize

Struct Serialize 

pub struct Serialize<F, W, D>
where F: FormatEncode, D: Encodable,
{ /* private fields */ }
Implements the Sink trait

Implementations

Source

impl<F, W, D> Serialize<F, W, D>

pub fn new(serializer: Serializer<F, W>) -> Serialize<F, W, D>
where W: AsyncWrite + Unpin,

Instantiates a new Serializer for the data type D from the given format and writer

pub fn is_ready(&self) -> bool

Returns true if the sink is ready to send another item, false if not

pub fn try_into_inner(self) -> Result<Serializer<F, W>, F>

Consumes the sink and attempts to return the underlying decoding format and writer.

If the stream is not in the Ready state, the underlying writer will be consumed, and the underlying format will be returned as an error.